/*
 * Machine dependent access functions for RTC registers.
 */
#ifndef _ASM_MC146818RTC_H
#define _ASM_MC146818RTC_H

#include <asm/arch/irqs.h>
#include <asm/io.h>

#ifndef RTC_PORT
#define RTC_PORT(x)	(0x70 + (x))
#define RTC_ALWAYS_BCD	1	/* RTC operates in binary mode */
#endif
#define RTC_IO_EXTENT	0x10	/* Only really two ports, but... */

/*
 * The yet supported machines all access the RTC index register via
 * an ISA port access but the way to access the date register differs ...
 */
#define CMOS_READ(addr) ({ \
outb_p((addr),RTC_PORT(0)); \
inb_p(RTC_PORT(1)); \
})
#define CMOS_WRITE(val, addr) ({ \
outb_p((addr),RTC_PORT(0)); \
outb_p((val),RTC_PORT(1)); \
})

#define RTC_HAS_IRQ	0	/* Don't support interrupt features.  */

#define RTC_CHECK_DRIVER_INIT()	1
#define RTC_MACH_INIT()						\
    do {							\
	request_region(RTC_PORT(0), RTC_IO_EXTENT, "rtc");	\
    } while(0)

/*
 * RTC year interpretation parameters:
 *   RTC_CENTURY_SWITCH: year line below which a century switch (+ 100
 *     years) should be a assumed
 *   RTC_MINYEAR: minimum real year that can be stored in the RTC
 */

/* If the epoch != 1900 (on some Alpha machines), there's no century switch */
#define RTC_CENTURY_SWITCH	(epoch != 1900 ? 69 : -1)
#define RTC_MINYEAR		(epoch != 1900 ? epoch : 1970)

#endif /* _ASM_MC146818RTC_H */
