/*
 * BK Id: SCCS/s.mc146818rtc.h 1.5 05/17/01 18:14:25 cort
 */
/*
 * Machine dependent access functions for RTC registers.
 */
#ifdef __KERNEL__
#ifndef __ASM_PPC_MC146818RTC_H
#define __ASM_PPC_MC146818RTC_H

#include <asm/io.h>

#ifndef RTC_PORT
#define RTC_PORT(x)	(0x70 + (x))
#define RTC_ALWAYS_BCD	1	/* RTC operates in binary mode */
#endif
#define RTC_IO_EXTENT	0x10	/* Only really two ports, but... */

/*
 * The yet supported machines all access the RTC index register via
 * an ISA port access but the way to access the date register differs ...
 */
#define CMOS_READ(addr) ({ \
outb_p((addr),RTC_PORT(0)); \
inb_p(RTC_PORT(1)); \
})
#define CMOS_WRITE(val, addr) ({ \
outb_p((addr),RTC_PORT(0)); \
outb_p((val),RTC_PORT(1)); \
})

#define RTC_HAS_IRQ	1
#define RTC_IRQ		8
#define RTC_IRQ_FLAGS	SA_INTERRUPT

#define RTC_CHECK_DRIVER_INIT()	1
#define RTC_MACH_INIT()						\
    do {							\
	if (check_region (RTC_PORT (0), RTC_IO_EXTENT))		\
	{							\
		printk(KERN_ERR "rtc: I/O port %d is not free.\n", RTC_PORT (0)); \
		return -EIO;					\
	}							\
	request_region(RTC_PORT(0), RTC_IO_EXTENT, "rtc");	\
    } while(0)
#define RTC_MACH_EXIT()						\
    do {							\
	release_region (RTC_PORT (0), RTC_IO_EXTENT);		\
    } while (0)

/*
 * RTC year interpretation parameters:
 *   RTC_CENTURY_SWITCH: year line below which a century switch (+ 100
 *     years) should be a assumed
 *   RTC_MINYEAR: minimum real year that can be stored in the RTC
 */

/* If the epoch != 1900 (on some Alpha machines), there's no century switch */
#define RTC_CENTURY_SWITCH	(epoch != 1900 ? 69 : -1)
#define RTC_MINYEAR		(epoch != 1900 ? epoch : 1970)

#endif /* __ASM_PPC_MC146818RTC_H */
#endif /* __KERNEL__ */
